#' Genetic correlation matrix for 62 traits
#'
#' Example genetic correlation matrix used in the vignette and examples.
#'
#' @format A numeric matrix.
#' @source Internal simulation
"Results_full_rg"
